# fast_serial

A basic serial port terminal that is fast to use

- programmable shortcuts (the "Action" list)
- easy filtering of the output (the "Filter" list)
- easy to modify for your special purposes

![fast_serial GUI](/resources/fast_serial_gui.png?raw=true "Fast Serial")

written in Python, you can easily modify it to fit your needs